# SearchSource: PDFs directory

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): search updates, get_masterdata, run_search, load_fixes, prep

based on [GROBID](https://github.com/kermitt2/grobid)

## Add the search source

```
colrev search -a colrev.pdfs_dir
```

## Links
